var servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape =
[
    [ "AppletCommands", "servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html#acd2571f1d4c40bd85fdd7955edc7e9d1", null ],
    [ "com::sun::star::drawing::Shape", "servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html#a337a0b131cd17ef2c08b51d5b37e04ef", null ],
    [ "AppletCode", "servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html#a2234c4ffa845e020894c41348a0da641", null ],
    [ "AppletCodeBase", "servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html#aca1cb9fc64440cc8e46810342200b4ae", null ],
    [ "AppletIsScript", "servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html#a7811e65a29eb3bacc12dff63e9879649", null ],
    [ "AppletName", "servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html#afe8c5f28b83e9f20dd4ff0bff7cd22f3", null ]
];